@@ -18,12 +18,13 @@ import sys
 import argparse
 import argcomplete
 import logging
-import kaptan
-from . import config
-from distutils.util import strtobool
-from . import log, util, exc, WorkspaceBuilder, Server
-from .util import ascii_lowercase, input
 import pkg_resources
+import kaptan
+from . import log, util, exc, WorkspaceBuilder, Server, config
+from .util import ascii_lowercase, input
+from .workspacebuilder import freeze
+from distutils.util import strtobool
+
 
 __version__ = pkg_resources.require("tmuxp")[0].version
 
@@ -195,7 +196,9 @@ def setup_logger(logger=None, level='INFO'):
         logger = logging.getLogger()
     if not logger.handlers:
         channel = logging.StreamHandler()
-        channel.setFormatter(log.LogFormatter())
+        channel.setFormatter(log.DebugLogFormatter())
+
+        #channel.setFormatter(log.LogFormatter())
         logger.setLevel(level)
         logger.addHandler(channel)
 
@@ -262,7 +265,11 @@ def load_workspace(config_file, args):
                 builder.session.attach_session()
         return
     except Exception as e:
+        import traceback
+
+        print(traceback.format_exc())
         logger.error(e)
+
         choice = prompt_choices(
             'Error loading workspace. (k)ill, (a)ttach, (d)etach?',
             choices=['k', 'a', 'd'],
@@ -274,13 +281,77 @@ def load_workspace(config_file, args):
             print('Session killed.')
         elif choice == 'a':
             if 'TMUX' in os.environ:
-                builder.session.switch_session()
+                builder.session.switch_client()
             else:
                 builder.session.attach_session()
         else:
             sys.exit()
 
 
+def command_freeze(args):
+    """ Import teamocil config to tmuxp format. """
+
+    t = Server(
+        socket_name=args.socket_name,
+        socket_path=args.socket_path
+    )
+
+    logger.error(args)
+    session = t.findWhere({
+        'session_name': args.session_name
+    })
+
+    sconf = freeze(session)
+    configparser = kaptan.Kaptan()
+    newconfig = config.inline(sconf)
+    configparser.import_config(newconfig)
+    config_format = prompt_choices('Convert to', choices=[
+                                    'yaml', 'json'], default='yaml')
+
+    if config_format == 'yaml':
+        newconfig = configparser.export(
+            'yaml', indent=2, default_flow_style=False, safe=True
+        )
+    elif config_format == 'json':
+        newconfig = configparser.export('json', indent=2)
+    else:
+        sys.exit('Unknown config format.')
+
+    print(newconfig)
+    print(
+        '---------------------------------------------------------------')
+    print(
+        'Configuration import does its best to convert teamocil files.\n')
+    if prompt_yes_no(
+        'The new config *WILL* require adjusting afterwards. Save config?'
+    ):
+        dest = None
+        while not dest:
+            dest_prompt = prompt('Save to: ', os.path.abspath(
+                os.path.join(config_dir, 'myimport.%s' % config_format)))
+            if os.path.exists(dest_prompt):
+                print('%s exists. Pick a new filename.' % dest_prompt)
+                continue
+
+            dest = dest_prompt
+
+        dest = os.path.abspath(os.path.relpath(dest))
+        if prompt_yes_no('Write to %s?' % dest):
+            buf = open(dest, 'w')
+            buf.write(newconfig)
+            buf.close()
+
+            print('Saved to %s.' % dest)
+    else:
+        print(
+            'tmuxp has examples in JSON and YAML format at <http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
+            'View tmuxp docs at <http://tmuxp.readthedocs.org/>'
+        )
+        sys.exit()
+
+
+
+
 def command_load(args):
     """ Load a session from a tmuxp session file. """
     if args.list:
@@ -309,7 +380,7 @@ def command_load(args):
             if config.in_cwd():
                 configfile = config.in_cwd()[0]
             else:
-                print('No tmuxp configs found in current directory.')
+                sys.exit('No tmuxp configs found in current directory.')
         else:
             configfile = args.config
         file_user = os.path.join(config_dir, configfile)
@@ -542,6 +613,9 @@ def command_convert(args):
                 print('written new config to <%s>.' % (newfile))
 
 
+
+
+
 def command_attach_session(args):
     """ Command to attach / switch client to a tmux session."""
     commands = []
@@ -624,6 +698,14 @@ def get_parser():
         type=str,
     ).completer = SessionCompleter
 
+    freeze = subparsers.add_parser('freeze')
+    freeze.set_defaults(callback=command_freeze)
+
+    freeze.add_argument(
+        dest='session_name',
+        type=str,
+    ).completer = SessionCompleter
+
     load = subparsers.add_parser('load')
 
     loadgroup = load.add_mutually_exclusive_group(required=True)
@@ -758,6 +840,8 @@ def main():
         command_import_teamocil(args)
     elif args.callback is command_import_tmuxinator:
         command_import_tmuxinator(args)
+    elif args.callback is command_freeze:
+        command_freeze(args)
     elif args.callback is command_attach_session:
         command_attach_session(args)
     elif args.callback is command_kill_session:
