@@ -5,20 +5,15 @@
     :copyright: Copyright 2013 Tony Narlock.
     :license: BSD, see LICENSE for details
 """
-from sh import ErrorReturnCode_1
 
 
-class TmuxSessionNotFound(Exception):
-    pass
-
 class TmuxSessionExists(Exception):
     pass
 
-class TmuxNoClientsRunning(Exception):
+
+class ConfigError(Exception):
     pass
 
-class TmuxNotRunning(Exception):
-    '''
-    tmux server not running.
-    '''
+
+class EmptyConfigException(Exception):
     pass
