@@ -12,6 +12,9 @@ from .helpers import TmuxTestCase
 
 logger = logging.getLogger(__name__)
 
+current_dir = os.path.abspath(os.path.dirname(__file__))
+example_dir = os.path.abspath(os.path.join(current_dir, '..', '..'))
+
 
 class TwoPaneTest(TmuxTestCase):
 
@@ -256,7 +259,7 @@ class WindowAutomaticRename(TmuxTestCase):
             w = s.attached_window()
             if w['window_name'] == 'man':
                 break
-            time.sleep(.01)
+            time.sleep(.2)
 
         self.assertEqual(w.get('window_name'), 'man')
 
@@ -265,50 +268,10 @@ class WindowAutomaticRename(TmuxTestCase):
             w = s.attached_window()
             if w['window_name'] != 'man':
                 break
-            time.sleep(.01)
+            time.sleep(.2)
 
         self.assertNotEqual(w.get('window_name'), 'man')
 
 
-class TestsToDo(object):
-
-    def test_uses_first_window_if_exists(self):
-        '''
-        if the session is already on the first window, use that.
-
-        this is useful if the user is already inside of a tmux session
-        '''
-
-    def test_same_session_already_exists_unclean(self):
-        '''
-        raise exception if session_name already exists and has multiple
-        windows the user could potentially be offered to add a cli argument to
-        override the session_name in config. Perhaps `-n` could be used to load
-        a config from file with overridden session_name.
-        '''
-
-    def test_inside_tmux_same_session_already_exists(self):
-        ''' same as above, but when the config file and the current $TMUX
-        session are the same '''
-
-    def test_inside_tmux_no_session_name_exists(self):
-        '''
-        if the session_name doesn't currently exist and the user is in tmux
-        rename the current session by the config / -n and build there.
-        '''
-
-    def testPaneProportions(self):
-        """
-        todo. checking the proportions of a pane on a grid allows
-        us to verify a window has been build correctly without
-        needing to see the tmux session itself.
-
-        we expect panes in a list to be ordered and show up to
-        their corresponding pane_index.
-        """
-        pass
-
-
 if __name__ == '__main__':
-    # t.socket_name = 'tmuxp_test'
     unittest.main()
