@@ -141,8 +141,8 @@ class WorkspaceBuilder(object):
                 assert(isinstance(p, Pane))
                 p = p
 
-            if 'layout' in wconf:
-                w.select_layout(wconf['layout'])
+                if 'layout' in wconf:
+                    w.select_layout(wconf['layout'])
 
     def iter_create_windows(self, s):
         ''' generator that creates tmux windows, yields :class:`Window` object
@@ -206,6 +206,9 @@ class WorkspaceBuilder(object):
                 p = w.attached_pane()
                 assert(isinstance(p, Pane))
 
+            if 'layout' in wconf:
+                w.select_layout(wconf['layout'])
+
             for cmd in pconf['shell_command']:
                 p.send_keys(cmd)
 
@@ -215,3 +218,35 @@ class WorkspaceBuilder(object):
             w.server._update_panes()
 
             yield p
+
+
+def freeze(session):
+    sconf = {}
+
+    sconf['session_name'] = session['session_name']
+
+    sconf['windows'] = []
+    for w in session.windows:
+        wconf = {}
+        wconf['options'] = w.show_window_options()
+        wconf['window_name'] = w.get('window_name')
+        wconf['layout'] = w.get('window_layout')
+        wconf['panes'] = []
+
+        if all(w.panes[0].get('pane_current_path') == p.get('pane_current_path') for p in w.panes):
+            wconf['shell_command_before'] = w.panes[0].get('pane_current_path')
+
+        for p in w.panes:
+            pconf = {}
+            pconf['shell_command'] = []
+            if 'shell_command_before' not in wconf:
+                pconf['shell_command'].append(
+                    'cd ' + p.get('pane_current_path'))
+            pconf['shell_command'].append(p.get('pane_current_command'))
+            wconf['panes'].append(pconf)
+            # logger.error(p)
+            # logger.error(dict(p))
+
+        sconf['windows'].append(wconf)
+
+    return sconf
